@@ -17,10 +17,10 @@
 
 #define H2CORE_VERSION_MAJOR 1
 #define H2CORE_VERSION_MINOR 2
-#define H2CORE_VERSION_PATCH 1
+#define H2CORE_VERSION_PATCH 2
 
 #define H2CORE_GIT_REVISION 
-#define H2CORE_VERSION "1.2.1-"
+#define H2CORE_VERSION "1.2.2-"
 #define H2CORE_IS_DEVEL_BUILD true
 
 
@@ -41,6 +41,12 @@
 #ifndef H2CORE_HAVE_BUNDLE
 /* #undef H2CORE_HAVE_BUNDLE */
 #endif
+#ifndef H2CORE_HAVE_APPIMAGE
+/* #undef H2CORE_HAVE_APPIMAGE */
+#endif
+#ifndef H2CORE_HAVE_DYNAMIC_JACK_CHECK
+/* #undef H2CORE_HAVE_DYNAMIC_JACK_CHECK */
+#endif
 #ifndef H2CORE_HAVE_LIBSNDFILE
 #define H2CORE_HAVE_LIBSNDFILE
 #endif
